@@ -27,6 +27,15 @@ def cache_to_django(
         django_model,
         cache_conf,
 ):
+    if redis_root.performance['enabled']:
+        if 'cache_to_django' not in redis_root.performance.keys():
+            redis_root.performance['cache_to_django'] = {
+                'requests': 0,
+                'time': 0
+            }
+        redis_root.performance['cache_to_django']['requests'] += 1
+        started_in = datetime.datetime.now()
+
     async def run_cache_to_django(
             redis_root,
             django_model,
@@ -92,6 +101,9 @@ def cache_to_django(
         django_model,
         cache_conf,
     ))
+    if redis_root.performance['enabled']:
+        ended_in = datetime.datetime.now()
+        redis_root.performance['cache_to_django']['time'] += (ended_in - started_in).total_seconds()
 
 
 async def update_or_create_django_instance_from_redis_instance(
@@ -299,6 +311,15 @@ def django_to_cache(
         django_model,
         cache_conf,
 ):
+    if redis_root.performance['enabled']:
+        if 'django_to_cache' not in redis_root.performance.keys():
+            redis_root.performance['django_to_cache'] = {
+                'requests': 0,
+                'time': 0
+            }
+        redis_root.performance['django_to_cache']['requests'] += 1
+        started_in = datetime.datetime.now()
+
     async def run_django_to_cache(
             redis_root,
             django_model,
@@ -356,6 +377,9 @@ def django_to_cache(
             cache_conf,
         )
     )
+    if redis_root.performance['enabled']:
+        ended_in = datetime.datetime.now()
+        redis_root.performance['django_to_cache']['time'] += (ended_in - started_in).total_seconds()
 
 
 async def update_or_create_redis_instance_from_django_instance(
