@@ -407,6 +407,9 @@ class RedisRoot:
             save_consistency=False,
             economy=False,
     ):
+        self.performance = {
+            'enabled': False,
+        }
         self.registered_models = []
         self.registered_django_models = {}
         if type(prefix) == str:
@@ -455,6 +458,16 @@ class RedisRoot:
             raise Exception(f'{django_model} is not registered')
 
     def get_or_create_redis_model_from_django_model(self, django_model):
+        if self.performance['enabled']:
+            if 'get_or_create_redis_model_from_django_model' not in self.performance.keys():
+                self.performance['get_or_create_redis_model_from_django_model'] = {
+                    'requests': 0,
+                    'time': 0
+                }
+            self.performance['get_or_create_redis_model_from_django_model']['requests'] += 1
+
+
+        started_in = datetime.datetime.now()
 
         def django_fields_to_redis_fields(django_model, redis_root, save_related_models, exclude_fields):
             redis_fields = {}
@@ -579,9 +592,13 @@ class RedisRoot:
                                                                    self)
         else:
             new_redis_model = create_redis_model_from_redis_fields(django_model, redis_fields, self)
+        ended_in = datetime.datetime.now()
+        if self.performance['enabled']:
+            self.performance['get_or_create_redis_model_from_django_model']['time'] += (ended_in-started_in).total_seconds()
         return new_redis_model
 
     def check_cache(self):
+        self.performance['enabled'] = True
         django_models_to_cache = self._get_django_models_to_cache()
         for django_model, cache_conf in django_models_to_cache.items():
 
@@ -599,9 +616,17 @@ class RedisRoot:
             print(f'{datetime.datetime.now()} - '
                   f'Cached {django_model} successfully'
                   f'\n\n\n')
+        for func_name, performance_data in self.performance.items():
+            if func_name != 'enabled':
+                print(f'\n'
+                      f'{func_name}'
+                      f'Requests: {performance_data["requests"]}\n'
+                      f'Time: {performance_data["time"]}s\n'
+                      f'Per request: {performance_data["time"]/performance_data["requests"]}s')
+
 
     def fast_get_keys_values(self, string):
-        keys = list(self.redis_instance.keys(string))
+        keys = list(self.redis_instance.scan_iter(string))
         values = self.redis_instance.mget(keys)
         results = dict(zip(keys, values))
         return results
@@ -857,7 +882,7 @@ class RedisRoot:
                 allowed = False
         return allowed
 
-    def _split_filtering(self, redis_model, filter_param):
+    def _split_filtering(self, filter_param):
         filter_field_name, filter_type = filter_param, 'exact'
         if '__' in filter_param:
             filter_param_split = filter_param.split('__')
@@ -956,8 +981,20 @@ class RedisRoot:
         return self._return_with_format(instances, return_dict)
 
     def get(self, django_model, return_dict=False, **filters):
+        if self.performance['enabled']:
+            if 'get' not in self.performance.keys():
+                self.performance['get'] = {
+                    'requests': 0,
+                    'time': 0
+                }
+            self.performance['get']['requests'] += 1
+            started_in = datetime.datetime.now()
         redis_model = self._django_model_to_redis_model(django_model)
-        return self.get_by_redis_model(redis_model, return_dict, **filters)
+        result = self.get_by_redis_model(redis_model, return_dict, **filters)
+        if self.performance['enabled']:
+            ended_in = datetime.datetime.now()
+            self.performance['get']['time'] += (ended_in - started_in).total_seconds()
+        return result
 
     def order(self, instances, field_name):
         reverse = False
@@ -1010,18 +1047,26 @@ class RedisRoot:
         return updated_data
 
     def update(self, django_model, instances=None, return_dict=False, renew_ttl=False, new_ttl=None, **fields_to_update):
+        if self.performance['enabled']:
+            if 'update' not in self.performance.keys():
+                self.performance['update'] = {
+                    'requests': 0,
+                    'time': 0
+                }
+            self.performance['update']['requests'] += 1
+            started_in = datetime.datetime.now()
         model = self._django_model_to_redis_model(django_model)
         model_name = model.__name__
         updated_datas = []
         if instances is None:
-            for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:*'):
+            for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:*'):
                 updated_data = self._update_by_instance_key(key, fields_to_update, renew_ttl, new_ttl)
                 if updated_data is not None:
                     updated_datas.append(updated_data)
         else:
             ids_to_update = get_ids_from_untyped_data(instances)
             for instance_id in ids_to_update:
-                for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:{instance_id}'):
+                for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:{instance_id}'):
                     updated_data = self._update_by_instance_key(key, fields_to_update, renew_ttl, new_ttl)
                     if updated_data is not None:
                         updated_datas.append(updated_data)
@@ -1035,7 +1080,11 @@ class RedisRoot:
                 updated_instance_qs = self.get_by_redis_model(updated_redis_model, id=updated_id)
                 updated_instance = updated_instance_qs[0]
                 updated_instances[updated_id] = updated_instance
-        return self._return_with_format(updated_instances, return_dict)
+        result = self._return_with_format(updated_instances, return_dict)
+        if self.performance['enabled']:
+            ended_in = datetime.datetime.now()
+            self.performance['update']['time'] += (ended_in - started_in).total_seconds()
+        return result
 
     def _delete_by_key(self, key):
         self.redis_instance.delete(key)
@@ -1044,19 +1093,19 @@ class RedisRoot:
         model = self._django_model_to_redis_model(django_model)
         model_name = model.__name__
         if instances is None:
-            for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:*'):
+            for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:*'):
                 self._delete_by_key(key)
         else:
             ids_to_delete = get_ids_from_untyped_data(instances)
             for instance_id in ids_to_delete:
-                for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:{instance_id}'):
+                for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:{instance_id}'):
                     self._delete_by_key(key)
 
     # def get_id_from_django_id(self, django_model, django_id):
     #     model_name = django_model.__name__
     #     check_types(django_id, int)
     #     result = False
-    #     for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:*:django_id'):
+    #     for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:*:django_id'):
     #         prefix, model_name, instance_id, field_name = key.split(':')
     #         value = int(self.redis_instance.get(key))
     #         if value == django_id:
@@ -1067,7 +1116,7 @@ class RedisRoot:
     #     model_name = django_model.__name__
     #     check_types(instance_id, int)
     #     result = False
-    #     for key in self.redis_instance.keys(f'{self.prefix}:{model_name}:{instance_id}:edited'):
+    #     for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:{instance_id}:edited'):
     #         prefix, model_name, instance_id, field_name = key.split(':')
     #         value = bool(int(self.redis_instance.get(key)))
     #         result = value
